@@ -21,10 +21,17 @@
 #ifndef _CSYNC_VIO_LOCAL_H
 #define _CSYNC_VIO_LOCAL_H
 
-csync_vio_handle_t OCSYNC_EXPORT *csync_vio_local_opendir(const char *name);
-int OCSYNC_EXPORT csync_vio_local_closedir(csync_vio_handle_t *dhandle);
-std::unique_ptr<csync_file_stat_t> OCSYNC_EXPORT csync_vio_local_readdir(csync_vio_handle_t *dhandle);
+#include <QString>
 
-int OCSYNC_EXPORT csync_vio_local_stat(const char *uri, csync_file_stat_t *buf);
+struct csync_vio_handle_t;
+namespace OCC {
+class Vfs;
+}
+
+csync_vio_handle_t OCSYNC_EXPORT *csync_vio_local_opendir(const QString &name);
+int OCSYNC_EXPORT csync_vio_local_closedir(csync_vio_handle_t *dhandle);
+std::unique_ptr<csync_file_stat_t> OCSYNC_EXPORT csync_vio_local_readdir(csync_vio_handle_t *dhandle, OCC::Vfs *vfs);
+
+int OCSYNC_EXPORT csync_vio_local_stat(const QString &uri, csync_file_stat_t *buf);
 
 #endif /* _CSYNC_VIO_LOCAL_H */
