@@ -59,6 +59,7 @@ constexpr auto networkUploadLimitSettingC = "networkUploadLimitSetting";
 constexpr auto networkDownloadLimitSettingC = "networkDownloadLimitSetting";
 constexpr auto networkUploadLimitC = "networkUploadLimit";
 constexpr auto networkDownloadLimitC = "networkDownloadLimit";
+constexpr auto encryptionCertificateSha256FingerprintC = "encryptionCertificateSha256Fingerprint";
 constexpr auto generalC = "General";
 
 constexpr auto dummyAuthTypeC = "dummy";
@@ -77,8 +78,8 @@ constexpr auto unbrandedRelativeConfigLocationC = "/Nextcloud/nextcloud.cfg";
 constexpr auto unbrandedCfgFileNameC = "nextcloud.cfg";
 
 // The maximum versions that this client can read
-constexpr auto maxAccountsVersion = 2;
-constexpr auto maxAccountVersion = 1;
+constexpr auto maxAccountsVersion = 13;
+constexpr auto maxAccountVersion = 13;
 
 constexpr auto serverHasValidSubscriptionC = "serverHasValidSubscription";
 }
@@ -149,6 +150,9 @@ void AccountManager::backwardMigrationSettingsKeys(QStringList *deleteKeys, QStr
     const auto settings = ConfigFile::settingsWithGroup(QLatin1String(accountsC));
     const auto accountsVersion = settings->value(QLatin1String(versionC)).toInt();
 
+    qCInfo(lcAccountManager) << "Checking for accounts versions.";
+    qCInfo(lcAccountManager) << "Config accounts version:" << accountsVersion;
+    qCInfo(lcAccountManager) << "Max accounts Version is set to:" << maxAccountsVersion;
     if (accountsVersion <= maxAccountsVersion) {
         const auto settingsChildGroups = settings->childGroups();
         for (const auto &accountId : settingsChildGroups) {
@@ -157,6 +161,7 @@ void AccountManager::backwardMigrationSettingsKeys(QStringList *deleteKeys, QStr
 
             if (accountVersion > maxAccountVersion) {
                 ignoreKeys->append(settings->group());
+                qCInfo(lcAccountManager) << "Ignoring account" << accountId << "because of version" << accountVersion;
             }
             settings->endGroup();
         }
@@ -235,41 +240,8 @@ bool AccountManager::restoreFromLegacySettings()
                     }
                 }
 
-                // Check the theme url to see if it is the same url that the oC config was for
-                const auto overrideUrl = Theme::instance()->overrideServerUrl();
-                const auto cleanOverrideUrl = overrideUrl.endsWith('/') ? overrideUrl.chopped(1) : overrideUrl;
-                qCInfo(lcAccountManager) << "Migrate: overrideUrl" << cleanOverrideUrl;
-
-                if (!cleanOverrideUrl.isEmpty()) {
-                    oCSettings->beginGroup(QLatin1String(accountsC));
-                    const auto accountsChildGroups = oCSettings->childGroups();
-                    for (const auto &accountId : accountsChildGroups) {
-                        oCSettings->beginGroup(accountId);
-                        const auto oCUrl = oCSettings->value(QLatin1String(urlC)).toString();
-                        const auto cleanOCUrl = oCUrl.endsWith('/') ? oCUrl.chopped(1) : oCUrl;
-
-                        // in case the urls are equal reset the settings object to read from
-                        // the ownCloud settings object
-                        qCInfo(lcAccountManager) << "Migrate oC config if " << cleanOCUrl << " == " << cleanOverrideUrl << ":"
-                                                 << (cleanOCUrl == cleanOverrideUrl ? "Yes" : "No");
-                        if (cleanOCUrl == cleanOverrideUrl) {
-                            qCInfo(lcAccountManager) << "Copy settings" << oCSettings->allKeys().join(", ");
-                            oCSettings->endGroup(); // current accountID group
-                            oCSettings->endGroup(); // accounts group
-                            settings = std::move(oCSettings);
-                            break;
-                        }
-
-                        oCSettings->endGroup();
-                    }
-
-                    if (oCSettings) {
-                        oCSettings->endGroup();
-                    }
-                } else {
-                    qCInfo(lcAccountManager) << "Copy settings" << oCSettings->allKeys().join(", ");
-                    settings = std::move(oCSettings);
-                }
+                qCInfo(lcAccountManager) << "Copy settings" << oCSettings->allKeys().join(", ");
+                settings = std::move(oCSettings);
 
                 ConfigFile::setDiscoveredLegacyConfigPath(configFileInfo.canonicalPath());
                 break;
@@ -306,7 +278,7 @@ void AccountManager::save(bool saveCredentials)
 {
     const auto settings = ConfigFile::settingsWithGroup(QLatin1String(accountsC));
     settings->setValue(QLatin1String(versionC), maxAccountsVersion);
-    for (const auto &acc : qAsConst(_accounts)) {
+    for (const auto &acc : std::as_const(_accounts)) {
         settings->beginGroup(acc->account()->id());
         saveAccountHelper(acc->account().data(), *settings, saveCredentials);
         settings->endGroup();
@@ -350,7 +322,7 @@ void AccountManager::saveAccountHelper(Account *account, QSettings &settings, bo
     settings.setValue(QLatin1String(serverColorC), account->_serverColor);
     settings.setValue(QLatin1String(serverTextColorC), account->_serverTextColor);
     settings.setValue(QLatin1String(serverHasValidSubscriptionC), account->serverHasValidSubscription());
-
+    settings.setValue(QLatin1String(encryptionCertificateSha256FingerprintC), account->encryptionCertificateFingerprint());
     if (!account->_skipE2eeMetadataChecksumValidation) {
         settings.remove(QLatin1String(skipE2eeMetadataChecksumValidationC));
     } else {
@@ -556,6 +528,8 @@ AccountPtr AccountManager::loadAccountHelper(QSettings &settings)
     });
     job->start();
 
+    acc->setEncryptionCertificateFingerprint(settings.value(QLatin1String(encryptionCertificateSha256FingerprintC)).toByteArray());
+
     // now the server cert, it is in the general group
     settings.beginGroup(QLatin1String(generalC));
     const auto certs = QSslCertificate::fromData(settings.value(caCertsKeyC).toByteArray());
