@@ -46,16 +46,7 @@ void HttpCredentialsGui::askFromUserAsync()
     // First, we will check what kind of auth we need.
     auto job = new DetermineAuthTypeJob(_account->sharedFromThis(), this);
     QObject::connect(job, &DetermineAuthTypeJob::authType, this, [this](DetermineAuthTypeJob::AuthType type) {
-        if (type == DetermineAuthTypeJob::OAuth) {
-            _asyncAuth.reset(new OAuth(_account, this));
-            _asyncAuth->_expectedUser = _account->davUser();
-            connect(_asyncAuth.data(), &OAuth::result,
-                this, &HttpCredentialsGui::asyncAuthResult);
-            connect(_asyncAuth.data(), &OAuth::destroyed,
-                this, &HttpCredentialsGui::authorisationLinkChanged);
-            _asyncAuth->start();
-            emit authorisationLinkChanged();
-        } else if (type == DetermineAuthTypeJob::Basic) {
+        if (type == DetermineAuthTypeJob::Basic) {
             showDialog();
         } else {
             // Shibboleth?
@@ -66,32 +57,6 @@ void HttpCredentialsGui::askFromUserAsync()
     job->start();
 }
 
-void HttpCredentialsGui::asyncAuthResult(OAuth::Result r, const QString &user,
-    const QString &token, const QString &refreshToken)
-{
-    switch (r) {
-    case OAuth::NotSupported:
-        showDialog();
-        _asyncAuth.reset(nullptr);
-        return;
-    case OAuth::Error:
-        _asyncAuth.reset(nullptr);
-        emit asked();
-        return;
-    case OAuth::LoggedIn:
-        break;
-    }
-
-    ASSERT(_user == user); // ensured by _asyncAuth
-
-    _password = token;
-    _refreshToken = refreshToken;
-    _ready = true;
-    persist();
-    _asyncAuth.reset(nullptr);
-    emit asked();
-}
-
 void HttpCredentialsGui::showDialog()
 {
     QString msg = tr("Please enter %1 password:<br>"
@@ -128,7 +93,6 @@ void HttpCredentialsGui::showDialog()
     connect(dialog, &QDialog::finished, this, [this, dialog](int result) {
         if (result == QDialog::Accepted) {
             _password = dialog->textValue();
-            _refreshToken.clear();
             _ready = true;
             persist();
         }
