@@ -363,18 +363,24 @@ void ShareModel::initShareManager()
     if (_manager.isNull() && sharingPossible) {
         _manager.reset(new ShareManager(_accountState->account(), this));
         connect(_manager.data(), &ShareManager::sharesFetched, this, &ShareModel::slotSharesFetched);
+        connect(_manager.data(), &ShareManager::sharedWithMeFetched, this, &ShareModel::slotSharedWithMeFetched);
         connect(_manager.data(), &ShareManager::shareCreated, this, [&] {
             _manager->fetchShares(_sharePath);
         });
         connect(_manager.data(), &ShareManager::linkShareCreated, this, &ShareModel::slotAddShare);
         connect(_manager.data(), &ShareManager::linkShareRequiresPassword, this, &ShareModel::requestPasswordForLinkShare);
         connect(_manager.data(), &ShareManager::serverError, this, [this](const int code, const QString &message) {
-            _hasInitialShareFetchCompleted = true;
-            Q_EMIT hasInitialShareFetchCompletedChanged();
+            if (!_hasInitialShareFetchCompleted) {
+                _hasInitialShareFetchCompleted = true;
+                Q_EMIT hasInitialShareFetchCompletedChanged();
+            }
+
+            qCWarning(lcShareModel) << "Error from server from ShareManager class and initShareManager" << code << message;
             emit serverError(code, message);
         });
 
         _manager->fetchShares(_sharePath);
+        _manager->fetchSharedWithMe(_sharePath);
     }
 }
 
@@ -385,7 +391,7 @@ void ShareModel::handlePlaceholderLinkShare()
     auto linkSharePresent = false;
     auto placeholderLinkSharePresent = false;
 
-    for (const auto &share : qAsConst(_shares)) {
+    for (const auto &share : std::as_const(_shares)) {
         const auto shareType = share->getShareType();
 
         if (!linkSharePresent && shareType == Share::TypeLink) {
@@ -415,7 +421,7 @@ void ShareModel::handleSecureFileDropLinkShare()
     auto linkSharePresent = false;
     auto secureFileDropLinkSharePresent = false;
 
-    for (const auto &share : qAsConst(_shares)) {
+    for (const auto &share : std::as_const(_shares)) {
         const auto shareType = share->getShareType();
 
         if (!linkSharePresent && shareType == Share::TypeLink) {
@@ -489,38 +495,13 @@ void ShareModel::slotSharesFetched(const QList<SharePtr> &shares)
     qCInfo(lcSharing) << "Fetched" << shares.count() << "shares";
 
     for (const auto &share : shares) {
-        if (share.isNull()) {
+        if (share.isNull() ||
+            share->account().isNull() ||
+            share->getUidOwner() != share->account()->davUser()) {
             continue;
-        } else if (const auto selfUserId = share->account()->davUser(); share->getUidOwner() != selfUserId) {
-            _displayShareOwner = true;
-            Q_EMIT displayShareOwnerChanged();
-            _shareOwnerDisplayName = share->getOwnerDisplayName();
-            Q_EMIT shareOwnerDisplayNameChanged();
-            _shareOwnerAvatar = "image://avatars/user-id="
-                + share->getUidOwner()
-                + "/local-account:"
-                + share->account()->displayName();
-            Q_EMIT shareOwnerAvatarChanged();
-
-            if (share->getShareType() == Share::TypeUser &&
-                share->getShareWith() &&
-                share->getShareWith()->shareWith() == selfUserId)
-            {
-                const auto userShare = share.objectCast<UserGroupShare>();
-                const auto expireDate = userShare->getExpireDate();
-                const auto daysToExpire = QDate::currentDate().daysTo(expireDate);
-                _sharedWithMeExpires = expireDate.isValid();
-                Q_EMIT sharedWithMeExpiresChanged();
-                _sharedWithMeRemainingTimeString = daysToExpire > 1
-                    ? tr("%1 days").arg(daysToExpire)
-                    :  daysToExpire > 0
-                        ? tr("1 day")
-                        : tr("Today");
-                Q_EMIT sharedWithMeRemainingTimeStringChanged();
-            }
-        } else {
-            slotAddShare(share);
         }
+
+        slotAddShare(share);
     }
 
     // Perform forward pass on shares and check for duplicate display names; store these indeces so
@@ -561,6 +542,47 @@ void ShareModel::slotSharesFetched(const QList<SharePtr> &shares)
     handleLinkShare();
 }
 
+void ShareModel::slotSharedWithMeFetched(const QList<OCC::SharePtr> &shares)
+{
+    qCInfo(lcSharing) << "Fetched" << shares.count() << "shares that have been shared_with_me";
+
+    for (const auto &share : shares) {
+        if (share.isNull()) {
+            continue;
+        }
+
+        const auto selfUserId = share->account()->davUser();
+        if (share->getUidOwner() == selfUserId) {
+            continue;
+        }
+
+        _displayShareOwner = true;
+        Q_EMIT displayShareOwnerChanged();
+        _shareOwnerDisplayName = share->getOwnerDisplayName();
+        Q_EMIT shareOwnerDisplayNameChanged();
+        _shareOwnerAvatar = QStringLiteral("image://avatars/user-id=%1/local-account:%2")
+            .arg(share->getUidOwner(), share->account()->displayName());
+        Q_EMIT shareOwnerAvatarChanged();
+
+        if (share->getShareType() == Share::TypeUser &&
+            share->getShareWith() &&
+            share->getShareWith()->shareWith() == selfUserId)
+        {
+            const auto userShare = share.objectCast<UserGroupShare>();
+            const auto expireDate = userShare->getExpireDate();
+            const auto daysToExpire = QDate::currentDate().daysTo(expireDate);
+            _sharedWithMeExpires = expireDate.isValid();
+            Q_EMIT sharedWithMeExpiresChanged();
+            _sharedWithMeRemainingTimeString = daysToExpire > 1
+                ? tr("%1 days").arg(daysToExpire)
+                :  daysToExpire == 1
+                    ? tr("1 day")
+                    : tr("Today");
+            Q_EMIT sharedWithMeRemainingTimeStringChanged();
+        }
+    }
+}
+
 void ShareModel::setupInternalLinkShare()
 {
     if (!_accountState ||
@@ -633,7 +655,10 @@ void ShareModel::slotAddShare(const SharePtr &share)
     const QPersistentModelIndex sharePersistentIndex(shareModelIndex);
     _shareIdIndexHash.insert(shareId, sharePersistentIndex);
 
-    connect(share.data(), &Share::serverError, this, &ShareModel::slotServerError);
+    connect(share.data(), &Share::serverError, this, [this] (int code, const QString &message) {
+        qCWarning(lcShareModel) << "Error from server from Share class" << code << message;
+        Q_EMIT serverError(code, message);
+    });
     connect(share.data(), &Share::passwordSetError, this, [this, shareId](const int code, const QString &message) {
         _shareIdRecentlySetPasswords.remove(shareId);
         slotSharePasswordSet(shareId);
@@ -656,10 +681,6 @@ void ShareModel::slotAddShare(const SharePtr &share)
         connect(userGroupShare.data(), &UserGroupShare::expireDateSet, this, [this, shareId]{ slotShareExpireDateSet(shareId); });
     }
 
-    if (_manager) {
-        connect(_manager.data(), &ShareManager::serverError, this, &ShareModel::slotServerError);
-    }
-
     handleLinkShare();
     Q_EMIT sharesChanged();
 }
@@ -708,12 +729,6 @@ void ShareModel::slotRemoveShareWithId(const QString &shareId)
     Q_EMIT sharesChanged();
 }
 
-void ShareModel::slotServerError(const int code, const QString &message)
-{
-    qCWarning(lcShareModel) << "Error from server" << code << message;
-    Q_EMIT serverError(code, message);
-}
-
 void ShareModel::slotAddSharee(const ShareePtr &sharee)
 {
     if(!sharee) {
@@ -788,7 +803,7 @@ QString ShareModel::avatarUrlForShare(const SharePtr &share) const
         const auto provider = QStringLiteral("image://tray-image-provider/");
         const auto userId = share->getShareWith()->shareWith();
         const auto avatarUrl = Utility::concatUrlPath(_accountState->account()->url(),
-                                                      QString("remote.php/dav/avatars/%1/%2.png").arg(userId, QString::number(64))).toString();
+                                                      QStringLiteral("remote.php/dav/avatars/%1/%2.png").arg(userId, QString::number(64))).toString();
         return QString(provider + avatarUrl);
     }
 
@@ -1073,26 +1088,6 @@ void ShareModel::toggleShareExpirationDateFromQml(const QVariant &share, const b
     toggleShareExpirationDate(ptr, enable);
 }
 
-void ShareModel::toggleShareNoteToRecipient(const SharePtr &share, const bool enable) const
-{
-    if (share.isNull()) {
-        return;
-    }
-
-    const QString note = enable ? tr("Enter a note for the recipient") : QString();
-    if (const auto linkShare = share.objectCast<LinkShare>()) {
-        linkShare->setNote(note);
-    } else if (const auto userGroupShare = share.objectCast<UserGroupShare>()) {
-        userGroupShare->setNote(note);
-    }
-}
-
-void ShareModel::toggleShareNoteToRecipientFromQml(const QVariant &share, const bool enable) const
-{
-    const auto ptr = share.value<SharePtr>();
-    toggleShareNoteToRecipient(ptr, enable);
-}
-
 void ShareModel::changePermissionModeFromQml(const QVariant &share, const OCC::ShareModel::SharePermissionsMode permissionMode)
 {
     const auto sharePtr = share.value<SharePtr>();
@@ -1464,7 +1459,7 @@ QString ShareModel::generatePassword()
     static const QRegularExpression lowercaseMatch("[a-z]");
     static const QRegularExpression uppercaseMatch("[A-Z]");
     static const QRegularExpression numberMatch("[0-9]");
-    static const QRegularExpression specialCharMatch(QString("[%1]").arg(specialChars.data()));
+    static const QRegularExpression specialCharMatch(QStringLiteral("[%1]").arg(specialChars.data()));
 
     static const std::map<std::string_view, QRegularExpression> matchMap{
         {lowercaseAlphabet, lowercaseMatch},
