@@ -59,6 +59,8 @@ private slots:
     void slotCreateDebugArchive();
     void loadMiscSettings();
     void slotShowLegalNotice();
+    void slotRemotePollIntervalChanged(int seconds);
+    void updatePollIntervalVisibility();
 #if defined(BUILD_UPDATER)
     void slotUpdateInfo();
     void slotUpdateChannelChanged();
