@@ -17,8 +17,10 @@
 
 #include <QWidget>
 
+#include "libsync/accountfwd.h"
 
 namespace OCC {
+class Account;
 
 namespace Ui {
     class NetworkSettings;
@@ -33,7 +35,7 @@ class NetworkSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit NetworkSettings(QWidget *parent = nullptr);
+    explicit NetworkSettings(const AccountPtr &account = {}, QWidget *parent = nullptr);
     ~NetworkSettings() override;
     [[nodiscard]] QSize sizeHint() const override;
 
@@ -54,6 +56,7 @@ private:
     void loadBWLimitSettings();
 
     Ui::NetworkSettings *_ui;
+    AccountPtr _account;
 };
 
 
