@@ -258,7 +258,12 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
             }
         } else {
             // We have an activity
-            return a._icon.isEmpty() ? colorIconPath.arg("activity.svg") : colorIconPath.arg(a._icon);
+            if (a._icon.isEmpty()) {
+                return colorIconPath.arg("activity.svg");
+            }
+
+            // using tray-image-provider here as it can read from URLs
+            return QStringLiteral("image://tray-image-provider/%1").arg(a._icon);
         }
     };
 
@@ -273,7 +278,7 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
         return displayLocation();
     case ActionsLinksRole: {
         QList<QVariant> customList;
-        foreach (ActivityLink activityLink, a._links) {
+        for (const auto &activityLink : std::as_const(a._links)) {
             customList << QVariant::fromValue(activityLink);
         }
         return customList;
@@ -302,14 +307,14 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
         case Activity::DummyMoreActivitiesAvailableType:
             return "Activity";
         case Activity::NotificationType:
+        case Activity::OpenSettingsNotificationType:
             return "Notification";
         case Activity::SyncFileItemType:
             return "File";
         case Activity::SyncResultType:
             return "Sync";
-        default:
-            return QVariant();
         }
+        break;
     }
     case ActionTextRole:
         if(a._subjectDisplay.isEmpty()) {
@@ -353,7 +358,8 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
     case IsCurrentUserFileActivityRole:
         return a._isCurrentUserFileActivity;
     case ThumbnailRole: {
-        if (a._type == Activity::NotificationType && !a._talkNotificationData.userAvatar.isEmpty()) {
+        if ((a._type == Activity::NotificationType || a._type == Activity::OpenSettingsNotificationType) &&
+            !a._talkNotificationData.userAvatar.isEmpty()) {
             return generateAvatarThumbnailMap(a._talkNotificationData.userAvatar);
         }
 
@@ -378,7 +384,7 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
         return QVariant::fromValue(a);
     }
 
-    return QVariant();
+    return {};
 }
 
 int ActivityListModel::rowCount(const QModelIndex &parent) const
@@ -604,7 +610,7 @@ void ActivityListModel::addIgnoredFileToList(const Activity &newActivity)
         return;
     }
 
-    foreach (Activity activity, _listOfIgnoredFiles) {
+    for (const auto &activity : _listOfIgnoredFiles) {
         if (activity._file == newActivity._file) {
             duplicate = true;
             break;
@@ -653,9 +659,10 @@ void ActivityListModel::removeActivityFromActivityList(const Activity &activity)
     }
 
     if (activity._type != Activity::ActivityType &&
-            activity._type != Activity::DummyFetchingActivityType &&
-            activity._type != Activity::DummyMoreActivitiesAvailableType &&
-            activity._type != Activity::NotificationType) {
+        activity._type != Activity::DummyFetchingActivityType &&
+        activity._type != Activity::DummyMoreActivitiesAvailableType &&
+        activity._type != Activity::NotificationType &&
+        activity._type != Activity::OpenSettingsNotificationType) {
 
         const auto notificationErrorsListIndex = _notificationErrorsLists.indexOf(activity);
         if (notificationErrorsListIndex != -1)
@@ -724,6 +731,8 @@ void ActivityListModel::slotTriggerDefaultAction(const int activityIndex)
         _currentInvalidFilenameDialog->open();
         ownCloudGui::raiseDialog(_currentInvalidFilenameDialog);
         return;
+    } else if (activity._type == Activity::OpenSettingsNotificationType) {
+        Q_EMIT showSettingsDialog();
     }
 
     if (!path.isEmpty()) {
