@@ -23,6 +23,7 @@
 #include "elidedlabel.h"
 
 class QProgressIndicator;
+class QNetworkReply;
 
 namespace OCC {
 
@@ -63,6 +64,7 @@ private slots:
     void slotSelectiveSyncClicked();
     void slotVirtualFileSyncClicked();
     void slotQuotaRetrieved(const QVariantMap &result);
+    void slotQuotaRetrievedWithError(QNetworkReply *reply);
 
 private:
     void setRadioChecked(QRadioButton *radio);
