@@ -141,7 +141,10 @@ bool copy_dir_recursive(QString from_dir, QString to_dir)
     from_dir += QDir::separator();
     to_dir += QDir::separator();
 
-    foreach (QString copy_file, dir.entryList(QDir::Files)) {
+    const auto fileEntries = dir.entryList(QDir::Files);
+    const auto dirEntries = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+
+    for (const auto &copy_file : fileEntries) {
         QString from = from_dir + copy_file;
         QString to = to_dir + copy_file;
 
@@ -150,7 +153,7 @@ bool copy_dir_recursive(QString from_dir, QString to_dir)
         }
     }
 
-    foreach (QString copy_dir, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+    for (const auto &copy_dir : dirEntries) {
         QString from = from_dir + copy_dir;
         QString to = to_dir + copy_dir;
 
@@ -453,6 +456,17 @@ QString ConfigFile::excludeFileFromSystem()
     return fi.absoluteFilePath();
 }
 
+void OCC::ConfigFile::cleanUpdaterConfiguration()
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    settings.beginGroup("Updater");
+    settings.remove("autoUpdateAttempted");
+    settings.remove("updateTargetVersion");
+    settings.remove("updateTargetVersionString");
+    settings.remove("updateAvailable");
+    settings.sync();
+}
+
 QString ConfigFile::backup(const QString &fileName) const
 {
     const QString baseFilePath = configPath() + fileName;
@@ -463,7 +477,7 @@ QString ConfigFile::backup(const QString &fileName) const
     }
 
     QString backupFile =
-        QString("%1.backup_%2%3")
+        QStringLiteral("%1.backup_%2%3")
             .arg(baseFilePath)
             .arg(QDateTime::currentDateTime().toString("yyyyMMdd_HHmmss"))
             .arg(versionString);
@@ -1260,6 +1274,12 @@ void ConfigFile::setupDefaultExcludeFilePaths(ExcludedFiles &excludedFiles)
     const auto userList = cfg.excludeFile(ConfigFile::UserScope);
     const auto legacyList = cfg.excludeFile(ConfigFile::LegacyScope);
 
+    if (Theme::instance()->isBranded() && QFile::exists(systemList) && QFile::copy(systemList, userList)) {
+        qCInfo(lcConfigFile) << "Overwriting user list" << userList << "with system list" << systemList;
+        excludedFiles.addExcludeFilePath(systemList);
+        return;
+    }
+
     if (!QFile::exists(userList)) {
         qCInfo(lcConfigFile) << "User defined ignore list does not exist:" << userList;
 
