@@ -20,13 +20,15 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcDeleteJob, "nextcloud.sync.networkjob.delete", QtInfoMsg)
 
-DeleteJob::DeleteJob(AccountPtr account, const QString &path, QObject *parent)
+DeleteJob::DeleteJob(AccountPtr account, const QString &path, const QMap<QByteArray, QByteArray> &headers, QObject *parent)
     : SimpleFileJob(account, path, parent)
+    , _headers(headers)
 {
 }
 
-DeleteJob::DeleteJob(AccountPtr account, const QUrl &url, QObject *parent)
+DeleteJob::DeleteJob(AccountPtr account, const QUrl &url, const QMap<QByteArray, QByteArray> &headers, QObject *parent)
     : SimpleFileJob(account, QString(), parent)
+    , _headers(headers)
     , _url(url)
 {
 }
@@ -38,6 +40,14 @@ void DeleteJob::start()
         req.setRawHeader("e2e-token", _folderToken);
     }
 
+    for (auto oneHeaderIt = _headers.begin(); oneHeaderIt != _headers.end(); ++oneHeaderIt) {
+        req.setRawHeader(oneHeaderIt.key(), oneHeaderIt.value());
+    }
+
+    if (_skipTrashbin) {
+        req.setRawHeader("X-NC-Skip-Trashbin", "true");
+    }
+
     if (_url.isValid()) {
         startRequest("DELETE", _url, req);
     } else {
@@ -55,4 +65,14 @@ void DeleteJob::setFolderToken(const QByteArray &folderToken)
     _folderToken = folderToken;
 }
 
+bool DeleteJob::skipTrashbin() const
+{
+    return _skipTrashbin;
+}
+
+void DeleteJob::setSkipTrashbin(bool skipTrashbin)
+{
+    _skipTrashbin = skipTrashbin;
+}
+
 } // namespace OCC
