@@ -225,6 +225,28 @@ void DiscoveryPhase::enqueueDirectoryToDelete(const QString &path, ProcessDirect
     }
 }
 
+void DiscoveryPhase::markPermanentDeletionRequests()
+{
+    // since we don't know in advance which files/directories need to be permanently deleted,
+    // we have to look through all of them at the end of the run
+    for (const auto &originalPath : _permanentDeletionRequests) {
+        const auto it = _deletedItem.find(originalPath);
+        if (it == _deletedItem.end()) {
+            qCWarning(lcDiscovery) << "didn't find an item for" << originalPath << "(yet)";
+            continue;
+        }
+
+        auto item = *it;
+        if (!(item->_instruction == CSYNC_INSTRUCTION_REMOVE || item->_direction == SyncFileItem::Up)) {
+            qCWarning(lcDiscovery) << "will not request permanent deletion for" << originalPath << "as the instruction is not CSYNC_INSTRUCTION_REMOVE, or the direction is not Up";
+            continue;
+        }
+
+        qCInfo(lcDiscovery) << "requested permanent server-side deletion for" << originalPath;
+        item->_wantsPermanentDeletion = true;
+    }
+}
+
 void DiscoveryPhase::startJob(ProcessDirectoryJob *job)
 {
     ENFORCE(!_currentRootJob);
@@ -242,6 +264,7 @@ void DiscoveryPhase::startJob(ProcessDirectoryJob *job)
             auto nextJob = _queuedDeletedDirectories.take(_queuedDeletedDirectories.firstKey());
             startJob(nextJob);
         } else {
+            markPermanentDeletionRequests();
             emit finished();
         }
     });
@@ -460,6 +483,11 @@ SyncFileItem::EncryptionStatus DiscoverySingleDirectoryJob::requiredEncryptionSt
     return _encryptionStatusRequired;
 }
 
+QByteArray DiscoverySingleDirectoryJob::certificateSha256Fingerprint() const
+{
+    return _e2eCertificateFingerprint;
+}
+
 static void propertyMapToRemoteInfo(const QMap<QString, QString> &map, RemotePermissions::MountedPermissionAlgorithm algorithm, RemoteInfo &result)
 {
     for (auto it = map.constBegin(); it != map.constEnd(); ++it) {
@@ -728,6 +756,7 @@ void DiscoverySingleDirectoryJob::metadataReceived(const QJsonDocument &json, in
         }
         _isFileDropDetected = e2EeFolderMetadata->isFileDropPresent();
         _encryptedMetadataNeedUpdate = e2EeFolderMetadata->encryptedMetadataNeedUpdate();
+        _e2eCertificateFingerprint = e2EeFolderMetadata->certificateSha256Fingerprint();
         _encryptionStatusRequired = EncryptionStatusEnums::fromEndToEndEncryptionApiVersion(_account->capabilities().clientSideEncryptionVersion());
         _encryptionStatusCurrent = e2EeFolderMetadata->existingMetadataEncryptionStatus();
 
