@@ -23,6 +23,14 @@ class TestBlacklist : public QObject
     Q_OBJECT
 
 private slots:
+    void initTestCase()
+    {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+    }
+
     void testBlacklistBasic_data()
     {
         QTest::addColumn<bool>("remote");
