@@ -38,6 +38,14 @@ class TestLockedFiles : public QObject
     Q_OBJECT
 
 private slots:
+    void initTestCase()
+    {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+    }
+
     void testBasicLockFileWatcher()
     {
         QTemporaryDir tmp;
