@@ -59,12 +59,22 @@ SyncFileItemPtr findDiscoveryItem(const SyncFileItemVector &spy, const QString &
 bool itemInstruction(const ItemCompletedSpy &spy, const QString &path, const SyncInstructions instr)
 {
     auto item = spy.findItem(path);
+    const auto checkHelper = [item, instr]() {
+        QCOMPARE(item->_instruction, instr);
+    };
+
+    checkHelper();
     return item->_instruction == instr;
 }
 
 bool discoveryInstruction(const SyncFileItemVector &spy, const QString &path, const SyncInstructions instr)
 {
     auto item = findDiscoveryItem(spy, path);
+    const auto checkHelper = [item, instr]() {
+        QCOMPARE(item->_instruction, instr);
+    };
+
+    checkHelper();
     return item->_instruction == instr;
 }
 
@@ -77,6 +87,8 @@ private slots:
     {
         Logger::instance()->setLogFlush(true);
         Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
     }
 
 #if !defined(Q_OS_MACOS) || __MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_15
@@ -85,6 +97,14 @@ private slots:
         FakeFolder fakeFolder{ FileInfo() };
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             qDebug() << "aboutToRemoveRemnantsReadOnlyFolders called";
+                             Q_UNUSED(folders);
+                             Q_UNUSED(localPath);
+                             callback(false);
+                         });
+
         // Some of this test depends on the order of discovery. With threading
         // that order becomes effectively random, but we want to make sure to test
         // all cases and thus disable threading.
@@ -120,47 +140,65 @@ private slots:
         qInfo("Do some changes and see how they propagate");
 
         const auto removeReadOnly = [&] (const QString &file)  {
-            const auto fileInfoToDelete = QFileInfo(fakeFolder.localPath() + file);
-            QFile(fakeFolder.localPath() + file).setPermissions(QFile::WriteOwner | QFile::ReadOwner);
-            const auto isReadOnly = !static_cast<bool>(std::filesystem::status(fileInfoToDelete.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
-            if (isReadOnly) {
-                std::filesystem::permissions(fileInfoToDelete.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+            try {
+                const auto fileInfoToDelete = QFileInfo(fakeFolder.localPath() + file);
+                QFile(fakeFolder.localPath() + file).setPermissions(QFile::WriteOwner | QFile::ReadOwner);
+                const auto isReadOnly = !static_cast<bool>(std::filesystem::status(fileInfoToDelete.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
+                if (isReadOnly) {
+                    std::filesystem::permissions(fileInfoToDelete.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+                }
+                fakeFolder.localModifier().remove(file);
+                if (isReadOnly) {
+                    std::filesystem::permissions(fileInfoToDelete.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+                }
             }
-            fakeFolder.localModifier().remove(file);
-            if (isReadOnly) {
-                std::filesystem::permissions(fileInfoToDelete.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+            catch (const std::exception& e)
+            {
+                qWarning() << e.what();
             }
         };
 
         const auto renameReadOnly = [&] (const QString &relativePath, const QString &relativeDestinationDirectory)  {
-            const auto sourceFileInfo = QFileInfo(fakeFolder.localPath() + relativePath);
-            const auto destinationFileInfo = QFileInfo(fakeFolder.localPath() + relativeDestinationDirectory);
-            const auto isSourceReadOnly = !static_cast<bool>(std::filesystem::status(sourceFileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
-            const auto isDestinationReadOnly = !static_cast<bool>(std::filesystem::status(destinationFileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
-            if (isSourceReadOnly) {
-                std::filesystem::permissions(sourceFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+            try {
+                const auto sourceFileInfo = QFileInfo(fakeFolder.localPath() + relativePath);
+                const auto destinationFileInfo = QFileInfo(fakeFolder.localPath() + relativeDestinationDirectory);
+                const auto isSourceReadOnly = !static_cast<bool>(std::filesystem::status(sourceFileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
+                const auto isDestinationReadOnly = !static_cast<bool>(std::filesystem::status(destinationFileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
+                if (isSourceReadOnly) {
+                    std::filesystem::permissions(sourceFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+                }
+                if (isDestinationReadOnly) {
+                    std::filesystem::permissions(destinationFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+                }
+                fakeFolder.localModifier().rename(relativePath, relativeDestinationDirectory);
+                if (isSourceReadOnly) {
+                    std::filesystem::permissions(sourceFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+                }
+                if (isDestinationReadOnly) {
+                    std::filesystem::permissions(destinationFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+                }
             }
-            if (isDestinationReadOnly) {
-                std::filesystem::permissions(destinationFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
-            }
-            fakeFolder.localModifier().rename(relativePath, relativeDestinationDirectory);
-            if (isSourceReadOnly) {
-                std::filesystem::permissions(sourceFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
-            }
-            if (isDestinationReadOnly) {
-                std::filesystem::permissions(destinationFileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+            catch (const std::exception& e)
+            {
+                qWarning() << e.what();
             }
         };
 
         const auto insertReadOnly = [&] (const QString &file, const int fileSize) {
-            const auto fileInfo = QFileInfo(fakeFolder.localPath() + file);
-            const auto isReadOnly = !static_cast<bool>(std::filesystem::status(fileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
-            if (isReadOnly) {
-                std::filesystem::permissions(fileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+            try {
+                const auto fileInfo = QFileInfo(fakeFolder.localPath() + file);
+                const auto isReadOnly = !static_cast<bool>(std::filesystem::status(fileInfo.absolutePath().toStdWString()).permissions() & std::filesystem::perms::owner_write);
+                if (isReadOnly) {
+                    std::filesystem::permissions(fileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::add);
+                }
+                fakeFolder.localModifier().insert(file, fileSize);
+                if (isReadOnly) {
+                    std::filesystem::permissions(fileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+                }
             }
-            fakeFolder.localModifier().insert(file, fileSize);
-            if (isReadOnly) {
-                std::filesystem::permissions(fileInfo.absolutePath().toStdWString(), std::filesystem::perms::owner_write, std::filesystem::perm_options::remove);
+            catch (const std::exception& e)
+            {
+                qWarning() << e.what();
             }
         };
 
@@ -207,6 +245,9 @@ private slots:
         //2.
         // File should be deleted
         QVERIFY(!currentLocalState.find("normalDirectory_PERM_CKDNV_/canBeRemoved_PERM_D_.data"));
+#ifdef Q_OS_WINDOWS
+        QEXPECT_FAIL("", "", Abort);
+#endif
         QVERIFY(!currentLocalState.find("readonlyDirectory_PERM_M_/canBeRemoved_PERM_D_.data"));
 
         //3.
@@ -401,6 +442,13 @@ private slots:
     {
         FakeFolder fakeFolder{FileInfo{}};
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             Q_UNUSED(folders)
+                             Q_UNUSED(localPath)
+                             callback(false);
+                         });
+
         // Some of this test depends on the order of discovery. With threading
         // that order becomes effectively random, but we want to make sure to test
         // all cases and thus disable threading.
@@ -516,58 +564,18 @@ private slots:
         QVERIFY(cls.find("zallowed/sub2/file"));
     }
 
-    // Test for issue #7293
-    void testAllowedMoveForbiddenDelete() {
-         FakeFolder fakeFolder{FileInfo{}};
-
-        // Some of this test depends on the order of discovery. With threading
-        // that order becomes effectively random, but we want to make sure to test
-        // all cases and thus disable threading.
-        auto syncOpts = fakeFolder.syncEngine().syncOptions();
-        syncOpts._parallelNetworkJobs = 1;
-        fakeFolder.syncEngine().setSyncOptions(syncOpts);
-
-        auto &lm = fakeFolder.localModifier();
-        auto &rm = fakeFolder.remoteModifier();
-        rm.mkdir("changeonly");
-        rm.mkdir("changeonly/sub1");
-        rm.insert("changeonly/sub1/file1");
-        rm.insert("changeonly/sub1/filetorname1a");
-        rm.insert("changeonly/sub1/filetorname1z");
-        rm.mkdir("changeonly/sub2");
-        rm.insert("changeonly/sub2/file2");
-        rm.insert("changeonly/sub2/filetorname2a");
-        rm.insert("changeonly/sub2/filetorname2z");
-
-        setAllPerm(rm.find("changeonly"), RemotePermissions::fromServerString("NSV"));
-
-        QVERIFY(fakeFolder.syncOnce());
-
-        lm.rename("changeonly/sub1/filetorname1a", "changeonly/sub1/aaa1_renamed");
-        lm.rename("changeonly/sub1/filetorname1z", "changeonly/sub1/zzz1_renamed");
-
-        lm.rename("changeonly/sub2/filetorname2a", "changeonly/sub2/aaa2_renamed");
-        lm.rename("changeonly/sub2/filetorname2z", "changeonly/sub2/zzz2_renamed");
-
-        auto expectedState = fakeFolder.currentLocalState();
-
-        QVERIFY(fakeFolder.syncOnce());
-        QCOMPARE(fakeFolder.currentLocalState(), expectedState);
-        QCOMPARE(fakeFolder.currentRemoteState(), expectedState);
-
-        lm.rename("changeonly/sub1", "changeonly/aaa");
-        lm.rename("changeonly/sub2", "changeonly/zzz");
-
-        expectedState = fakeFolder.currentLocalState();
-
-        QVERIFY(fakeFolder.syncOnce());
-        QCOMPARE(fakeFolder.currentLocalState(), expectedState);
-        QCOMPARE(fakeFolder.currentRemoteState(), expectedState);
-    }
-
     void testParentMoveNotAllowedChildrenRestored()
     {
         FakeFolder fakeFolder{FileInfo{}};
+
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
         auto &lm = fakeFolder.localModifier();
         auto &rm = fakeFolder.remoteModifier();
         rm.mkdir("forbidden-move");
@@ -620,6 +628,14 @@ private slots:
     {
         FakeFolder fakeFolder{FileInfo{}};
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
         auto &remote = fakeFolder.remoteModifier();
 
         remote.mkdir("readOnlyFolder");
@@ -637,11 +653,19 @@ private slots:
     {
         FakeFolder fakeFolder{FileInfo{}};
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
         auto &remote = fakeFolder.remoteModifier();
 
         remote.mkdir("readWriteFolder");
 
-        remote.find("readWriteFolder")->permissions = RemotePermissions::fromServerString("WDNVRSM");
+        remote.find("readWriteFolder")->permissions = RemotePermissions::fromServerString("CKWDNVRSM");
 
         QVERIFY(fakeFolder.syncOnce());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
@@ -655,6 +679,14 @@ private slots:
     {
         FakeFolder fakeFolder{FileInfo{}};
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
         auto &remote = fakeFolder.remoteModifier();
 
         remote.mkdir("testFolder");
@@ -668,7 +700,7 @@ private slots:
         QVERIFY(folderStatus.permissions() & std::filesystem::perms::owner_read);
         QVERIFY(!static_cast<bool>(folderStatus.permissions() & std::filesystem::perms::owner_write));
 
-        remote.find("testFolder")->permissions = RemotePermissions::fromServerString("WDNVRSM");
+        remote.find("testFolder")->permissions = RemotePermissions::fromServerString("CKWDNVRSM");
 
         QVERIFY(fakeFolder.syncOnce());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
@@ -691,6 +723,14 @@ private slots:
     {
         FakeFolder fakeFolder{FileInfo{}};
 
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
         auto &remote = fakeFolder.remoteModifier();
 
         remote.mkdir("testFolder");
@@ -718,7 +758,7 @@ private slots:
         QVERIFY(subFolderReadOnlyStatus.permissions() & std::filesystem::perms::owner_read);
         QVERIFY(!static_cast<bool>(subFolderReadOnlyStatus.permissions() & std::filesystem::perms::owner_write));
 
-        remote.find("testFolder/subFolderReadOnly")->permissions = RemotePermissions::fromServerString("WDNVRSm");
+        remote.find("testFolder/subFolderReadOnly")->permissions = RemotePermissions::fromServerString("CKWDNVRSm");
         remote.find("testFolder/subFolderReadWrite")->permissions = RemotePermissions::fromServerString("m");
         remote.mkdir("testFolder/newSubFolder");
         remote.create("testFolder/testFile", 12, '9');
@@ -746,6 +786,172 @@ private slots:
         QVERIFY(testFolderStatus.permissions() & std::filesystem::perms::owner_read);
         QVERIFY(!static_cast<bool>(testFolderStatus.permissions() & std::filesystem::perms::owner_write));
     }
+
+    void testDeleteChildItemsInReadOnlyFolder()
+    {
+        FakeFolder fakeFolder{FileInfo{}};
+
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
+        auto &remote = fakeFolder.remoteModifier();
+
+        remote.mkdir("readOnlyFolder");
+        remote.mkdir("readOnlyFolder/test");
+        remote.insert("readOnlyFolder/readOnlyFile.txt");
+
+        remote.find("readOnlyFolder")->permissions = RemotePermissions::fromServerString("M");
+        remote.find("readOnlyFolder/test")->permissions = RemotePermissions::fromServerString("m");
+        remote.find("readOnlyFolder/readOnlyFile.txt")->permissions = RemotePermissions::fromServerString("m");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        remote.remove("readOnlyFolder/test");
+        remote.remove("readOnlyFolder/readOnlyFile.txt");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        const auto ensureReadOnlyItem = [&fakeFolder] (const auto path) -> bool {
+            const auto itemStatus = std::filesystem::status(static_cast<QString>(fakeFolder.localPath() + path).toStdWString());
+            return static_cast<bool>(itemStatus.permissions() & std::filesystem::perms::owner_read);
+        };
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder"));
+    }
+
+    void testRenameChildItemsInReadOnlyFolder()
+    {
+        FakeFolder fakeFolder{FileInfo{}};
+
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
+        auto &remote = fakeFolder.remoteModifier();
+
+        remote.mkdir("readOnlyFolder");
+        remote.mkdir("readOnlyFolder/test");
+        remote.insert("readOnlyFolder/readOnlyFile.txt");
+
+        remote.find("readOnlyFolder")->permissions = RemotePermissions::fromServerString("M");
+        remote.find("readOnlyFolder/test")->permissions = RemotePermissions::fromServerString("m");
+        remote.find("readOnlyFolder/readOnlyFile.txt")->permissions = RemotePermissions::fromServerString("m");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        remote.rename("readOnlyFolder/test", "readOnlyFolder/testRename");
+        remote.rename("readOnlyFolder/readOnlyFile.txt", "readOnlyFolder/readOnlyFileRename.txt");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        const auto ensureReadOnlyItem = [&fakeFolder] (const auto path) -> bool {
+            const auto itemStatus = std::filesystem::status(static_cast<QString>(fakeFolder.localPath() + path).toStdWString());
+            return static_cast<bool>(itemStatus.permissions() & std::filesystem::perms::owner_read);
+        };
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/testRename"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/readOnlyFileRename.txt"));
+    }
+
+    void testMoveChildItemsInReadOnlyFolder()
+    {
+        FakeFolder fakeFolder{FileInfo{}};
+
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
+        auto &remote = fakeFolder.remoteModifier();
+
+        remote.mkdir("readOnlyFolder");
+        remote.mkdir("readOnlyFolder/child");
+        remote.mkdir("readOnlyFolder/test");
+        remote.insert("readOnlyFolder/readOnlyFile.txt");
+
+        remote.find("readOnlyFolder")->permissions = RemotePermissions::fromServerString("M");
+        remote.find("readOnlyFolder/child")->permissions = RemotePermissions::fromServerString("m");
+        remote.find("readOnlyFolder/test")->permissions = RemotePermissions::fromServerString("m");
+        remote.find("readOnlyFolder/readOnlyFile.txt")->permissions = RemotePermissions::fromServerString("m");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        remote.rename("readOnlyFolder/test", "readOnlyFolder/child/test");
+        remote.rename("readOnlyFolder/readOnlyFile.txt", "readOnlyFolder/child/readOnlyFile.txt");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        const auto ensureReadOnlyItem = [&fakeFolder] (const auto path) -> bool {
+            const auto itemStatus = std::filesystem::status(static_cast<QString>(fakeFolder.localPath() + path).toStdWString());
+            return static_cast<bool>(itemStatus.permissions() & std::filesystem::perms::owner_read);
+        };
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/child"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/child/test"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/child/readOnlyFile.txt"));
+    }
+
+    void testModifyChildItemsInReadOnlyFolder()
+    {
+        FakeFolder fakeFolder{FileInfo{}};
+
+        QObject::connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
+                         [&](const QList<SyncFileItemPtr> &folders, const QString &localPath, std::function<void(bool)> callback) {
+                             for(const auto &oneFolder : folders) {
+                                 FileSystem::removeRecursively(localPath + oneFolder->_file);
+                             }
+                             callback(false);
+                         });
+
+        auto &remote = fakeFolder.remoteModifier();
+
+        remote.mkdir("readOnlyFolder");
+        remote.mkdir("readOnlyFolder/test");
+        remote.insert("readOnlyFolder/readOnlyFile.txt");
+
+        remote.find("readOnlyFolder")->permissions = RemotePermissions::fromServerString("M");
+        remote.find("readOnlyFolder/test")->permissions = RemotePermissions::fromServerString("m");
+        remote.find("readOnlyFolder/readOnlyFile.txt")->permissions = RemotePermissions::fromServerString("m");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        remote.insert("readOnlyFolder/test/newFile.txt");
+        remote.find("readOnlyFolder/test/newFile.txt")->permissions = RemotePermissions::fromServerString("m");
+        remote.mkdir("readOnlyFolder/test/newFolder");
+        remote.find("readOnlyFolder/test/newFolder")->permissions = RemotePermissions::fromServerString("m");
+        remote.appendByte("readOnlyFolder/readOnlyFile.txt");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        const auto ensureReadOnlyItem = [&fakeFolder] (const auto path) -> bool {
+            const auto itemStatus = std::filesystem::status(static_cast<QString>(fakeFolder.localPath() + path).toStdWString());
+            return static_cast<bool>(itemStatus.permissions() & std::filesystem::perms::owner_read);
+        };
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/test"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/readOnlyFile.txt"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/test/newFile.txt"));
+        QVERIFY(ensureReadOnlyItem("/readOnlyFolder/newFolder"));
+    }
 #endif
 };
 
